# frozen_string_literal: true

module JSONAPI
  module SimpleClient
    module QueryParams
      class << self
        # @param params [Hash]
        # @return [Hash]
        def parse(params)
          params.each_with_object({}) do |(key, value), hash|
            hash.merge!(
              value.is_a?(Hash) ? parse_nested_param(key, value) : { key => parse_param(value) }
            )
          end
        end

        private

        # @param root [String]
        # @param value [Hash]
        # @return [Hash]
        def parse_nested_param(root, value)
          value.map { |key, nested_value| ["#{root}[#{key}]", parse_param(nested_value)] }.to_h
        end

        # @param value [Object]
        # @raise [ArgumentError] if value is a Hash.
        # @return [String]
        def parse_param(value)
          case value
          when Hash
            raise ArgumentError, "Multi nested params are not supported."
          when Array
            value.join(",")
          else
            value.to_s
          end
        end
      end
    end
  end
end
